@@ -253,18 +253,7 @@ class E6xDialect(default.DefaultDialect):
         return client.get_schema_names()
 
     def get_view_names(self, connection, schema=None, **kw):
-        # Hive does not provide functionality to query tableType
-        # This allows reflection to not crash at the cost of being inaccurate
-        engine = connection
-        if isinstance(connection, Engine):
-            cursor = connection.raw_connection().connection.cursor()
-        elif isinstance(connection, Connection):
-            cursor = connection.connection.cursor()
-        else:
-            raise Exception("Got type of object {typ}".format(typ=type(connection)))
-
-        client = cursor.connection
-        return client.getTables("default")
+        return []
 
     def _get_table_columns(self, connection, table):
         try:
@@ -338,7 +327,18 @@ class E6xDialect(default.DefaultDialect):
         return []
 
     def get_table_names(self, connection, schema=None, **kw):
-        return self.get_view_names(connection)
+        # Hive does not provide functionality to query tableType
+        # This allows reflection to not crash at the cost of being inaccurate
+        engine = connection
+        if isinstance(connection, Engine):
+            cursor = connection.raw_connection().connection.cursor()
+        elif isinstance(connection, Connection):
+            cursor = connection.connection.cursor()
+        else:
+            raise Exception("Got type of object {typ}".format(typ=type(connection)))
+
+        client = cursor.connection
+        return client.getTables(schema)
 
     def do_rollback(self, dbapi_connection):
         # No transactions for Hive
